import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import AnalyzeReaderEngagement from './analyzeReaderEngagement';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('successfully analyzes reader engagement', async () => {
  fetchMock.get('/api/analyzeReaderEngagement?postId=1', { status: 200, body: { engagementScore: 85 } });

  await act(async () => { render(<MemoryRouter><AnalyzeReaderEngagement postId="1" /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByText('Analyze Engagement')); });

  expect(fetchMock.calls('/api/analyzeReaderEngagement')).toHaveLength(1);
  expect(screen.getByText('Engagement Score: 85')).toBeInTheDocument();
}, 10000);

test('fails to analyze reader engagement with an error message', async () => {
  fetchMock.get('/api/analyzeReaderEngagement?postId=1', { status: 500, body: { message: 'Server Error' } });

  await act(async () => { render(<MemoryRouter><AnalyzeReaderEngagement postId="1" /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByText('Analyze Engagement')); });

  expect(fetchMock.calls('/api/analyzeReaderEngagement')).toHaveLength(1);
  expect(screen.getByText('Error analyzing engagement')).toBeInTheDocument();
}, 10000);

