import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import RetrievePostAnalytics from './retrievePostAnalytics';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('successfully retrieves analytics for a post', async () => {
  fetchMock.get('/api/getPostAnalytics?postId=1', { status: 200, body: { views: 10, shares: 5 } });

  await act(async () => { render(<MemoryRouter><RetrievePostAnalytics postId="1" /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByText('Get Analytics')); });

  expect(fetchMock.calls('/api/getPostAnalytics')).toHaveLength(1);
  expect(screen.getByText('Views: 10')).toBeInTheDocument();
  expect(screen.getByText('Shares: 5')).toBeInTheDocument();
}, 10000);

test('fails to retrieve analytics for a post with an error message', async () => {
  fetchMock.get('/api/getPostAnalytics?postId=1', { status: 500, body: { message: 'Server Error' } });

  await act(async () => { render(<MemoryRouter><RetrievePostAnalytics postId="1" /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByText('Get Analytics')); });

  expect(fetchMock.calls('/api/getPostAnalytics')).toHaveLength(1);
  expect(screen.getByText('Error retrieving analytics')).toBeInTheDocument();
}, 10000);

