import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import InAppNotifications from './inAppNotifications';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('Successfully displays in-app notifications.', async () => {
  fetchMock.get('/api/getNotifications', { notifications: ['Notification 1'] });

  await act(async () => { render(<MemoryRouter><InAppNotifications /></MemoryRouter>); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Notification 1')).toBeInTheDocument();
}, 10000);

test('Fails to display in-app notifications.', async () => {
  fetchMock.get('/api/getNotifications', 500);

  await act(async () => { render(<MemoryRouter><InAppNotifications /></MemoryRouter>); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Failed to load notifications')).toBeInTheDocument();
}, 10000);

