import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import NotificationDeliveryTracking from './notificationDeliveryTracking';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('Successfully tracks delivery status of notifications.', async () => {
  fetchMock.get('/api/getDeliveryStatus', { status: 'Delivered' });

  await act(async () => { render(<MemoryRouter><NotificationDeliveryTracking /></MemoryRouter>); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Delivered')).toBeInTheDocument();
}, 10000);

test('Fails to track delivery status of notifications.', async () => {
  fetchMock.get('/api/getDeliveryStatus', 500);

  await act(async () => { render(<MemoryRouter><NotificationDeliveryTracking /></MemoryRouter>); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Failed to track delivery status')).toBeInTheDocument();
}, 10000);

