import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import DisplayTotalReviews from './displayTotalReviews';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('Displaying total number of reviews should show correct count', async () => {
  fetchMock.get('/api/reviews/count?productId=123', { count: 100 });

  await act(async () => { render(<MemoryRouter><DisplayTotalReviews productId="123" /></MemoryRouter>); });

  expect(fetchMock.calls('/api/reviews/count?productId=123')).toHaveLength(1);
  expect(screen.getByText('Total Reviews: 100')).toBeInTheDocument();
}, 10000);

test('Displaying total number of reviews should fail to fetch data', async () => {
  fetchMock.get('/api/reviews/count?productId=123', { status: 500 });

  await act(async () => { render(<MemoryRouter><DisplayTotalReviews productId="123" /></MemoryRouter>); });

  expect(fetchMock.calls('/api/reviews/count?productId=123')).toHaveLength(1);
  expect(screen.getByText('Failed to load total reviews count')).toBeInTheDocument();
}, 10000);

