import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import EventApp from './eventCancellation';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('Displays successful cancellation message upon event cancellation', async () => {
  fetchMock.post('/api/event/cancel', { success: true });

  await act(async () => { render(<MemoryRouter><EventApp /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByTestId('cancel-event-btn')); });

  expect(fetchMock.calls().length).toBe(1);
  expect(screen.getByText('Event successfully cancelled')).toBeInTheDocument();
}, 10000);

test('Displays error message upon failing to cancel an event', async () => {
  fetchMock.post('/api/event/cancel', 400);

  await act(async () => { render(<MemoryRouter><EventApp /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByTestId('cancel-event-btn')); });

  expect(fetchMock.calls().length).toBe(1);
  expect(screen.getByText('Failed to cancel the event')).toBeInTheDocument();
}, 10000);

