import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import EventApp from './eventSearch';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('Displays accurate search results for events based on filters', async () => {
  fetchMock.get('/api/event/search?query=concert', { results: [{ name: 'Concert Event' }] });

  await act(async () => { render(<MemoryRouter><EventApp /></MemoryRouter>); });
  await act(async () => { fireEvent.change(screen.getByTestId('search-input'), { target: { value: 'concert' }}); });
  await act(async () => { fireEvent.click(screen.getByTestId('search-btn')); });

  expect(fetchMock.calls().length).toBe(1);
  expect(screen.getByText('Concert Event')).toBeInTheDocument();
}, 10000);

test('Displays error message when search results are unavailable', async () => {
  fetchMock.get('/api/event/search?query=concert', 404);

  await act(async () => { render(<MemoryRouter><EventApp /></MemoryRouter>); });
  await act(async () => { fireEvent.change(screen.getByTestId('search-input'), { target: { value: 'concert' }}); });
  await act(async () => { fireEvent.click(screen.getByTestId('search-btn')); });

  expect(fetchMock.calls().length).toBe(1);
  expect(screen.getByText('No event results found')).toBeInTheDocument();
}, 10000);