import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import EventApp from './sponsorDisplay';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('Displays sponsors and partners on event pages', async () => {
  fetchMock.get('/api/event/sponsors', { sponsors: ['Sponsor 1', 'Sponsor 2'], partners: ['Partner 1'] });

  await act(async () => { render(<MemoryRouter><EventApp /></MemoryRouter>); });

  expect(fetchMock.calls().length).toBe(1);
  expect(screen.getByText('Sponsor 1')).toBeInTheDocument();
  expect(screen.getByText('Partner 1')).toBeInTheDocument();
}, 10000);

test('Displays error message when sponsors and partners are unavailable', async () => {
  fetchMock.get('/api/event/sponsors', 404);

  await act(async () => { render(<MemoryRouter><EventApp /></MemoryRouter>); });

  expect(fetchMock.calls().length).toBe(1);
  expect(screen.getByText('Sponsors and partners are unavailable')).toBeInTheDocument();
}, 10000);

