import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import FitnessApp from './logYogaSession';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('User can log a yoga session successfully.', async () => {
  fetchMock.post('/api/logYogaSession', { status: 200, body: { success: true } });

  await act(async () => {
    render(<MemoryRouter><FitnessApp /></MemoryRouter>);
  });
  await act(async () => {
    fireEvent.change(screen.getByTestId('yoga-session-type'), { target: { value: 'Ashtanga' } });
    fireEvent.click(screen.getByTestId('submit-yoga-session'));
  });

  expect(fetchMock.called('/api/logYogaSession')).toBeTruthy();
  expect(screen.getByText('Yoga session logged successfully')).toBeInTheDocument();
}, 10000);

test('User sees an error message when logging a yoga session fails.', async () => {
  fetchMock.post('/api/logYogaSession', { status: 500, body: { error: 'Failed to log session' } });

  await act(async () => {
    render(<MemoryRouter><FitnessApp /></MemoryRouter>);
  });
  await act(async () => {
    fireEvent.change(screen.getByTestId('yoga-session-type'), { target: { value: 'Ashtanga' } });
    fireEvent.click(screen.getByTestId('submit-yoga-session'));
  });

  expect(fetchMock.called('/api/logYogaSession')).toBeTruthy();
  expect(screen.getByText('Failed to log session')).toBeInTheDocument();
}, 10000);

