import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import App from './trackWorkoutIntensity';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('tracks workout intensity successfully and displays intensity', async () => {
  fetchMock.get('/api/track-intensity', { status: 200, body: { intensity: 'Moderate' } });

  await act(async () => { render(<MemoryRouter><App /></MemoryRouter>); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Workout intensity: Moderate')).toBeInTheDocument();
}, 10000);

test('fails to track workout intensity and displays an error message', async () => {
  fetchMock.get('/api/track-intensity', { status: 500, body: { error: 'Server error' } });

  await act(async () => { render(<MemoryRouter><App /></MemoryRouter>); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Failed to track workout intensity.')).toBeInTheDocument();
}, 10000);