import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import JobListingPage from './filterJobPostsByCategory';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('allows job seekers to filter job posts by categories successfully.', async () => {
  fetchMock.get('/api/jobPosts?category=IT', [{ id: 1, title: 'Backend Developer' }]);

  await act(async () => {
    render(
      <MemoryRouter>
        <JobListingPage />
      </MemoryRouter>
    );
  });

  await act(async () => {
    fireEvent.change(screen.getByLabelText('Category'), { target: { value: 'IT' } });
    fireEvent.click(screen.getByText('Filter'));
  });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Backend Developer')).toBeInTheDocument();
}, 10000);

test('shows an error message when filtering by categories fails.', async () => {
  fetchMock.get('/api/jobPosts?category=IT', 500);

  await act(async () => {
    render(
      <MemoryRouter>
        <JobListingPage />
      </MemoryRouter>
    );
  });

  await act(async () => {
    fireEvent.change(screen.getByLabelText('Category'), { target: { value: 'IT' } });
    fireEvent.click(screen.getByText('Filter'));
  });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Error filtering job posts.')).toBeInTheDocument();
}, 10000);

