import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import CourseRecommendation from './courseRecommendation';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('Successfully displays course recommendations', async () => {
  fetchMock.get('/course-recommendations', { status: 200, body: [{ id: 1, title: 'Course 1' }] });

  await act(async () => { render(<MemoryRouter><CourseRecommendation /></MemoryRouter>); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Course 1')).toBeInTheDocument();
}, 10000);

test('Fails to display course recommendations', async () => {
  fetchMock.get('/course-recommendations', { status: 500, body: 'Error' });

  await act(async () => { render(<MemoryRouter><CourseRecommendation /></MemoryRouter>); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Recommendations failed')).toBeInTheDocument();
}, 10000);

