import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import LeaveProductReview from './leaveProductReview';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('Leave Product Review successfully posts a review.', async () => {
  fetchMock.post('/api/reviews', { status: 200 });

  await act(async () => { render(<MemoryRouter><LeaveProductReview /></MemoryRouter>); });
  await act(async () => { fireEvent.change(screen.getByTestId('review-input'), { target: { value: 'Great product!' } }); });
  await act(async () => { fireEvent.click(screen.getByTestId('post-review-button')); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Review posted')).toBeInTheDocument();
}, 10000);

test('Leave Product Review fails and displays error message.', async () => {
  fetchMock.post('/api/reviews', { status: 500 });

  await act(async () => { render(<MemoryRouter><LeaveProductReview /></MemoryRouter>); });
  await act(async () => { fireEvent.change(screen.getByTestId('review-input'), { target: { value: 'Great product!' } }); });
  await act(async () => { fireEvent.click(screen.getByTestId('post-review-button')); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Failed to post review')).toBeInTheDocument();
}, 10000);

