import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import UserNotifications from './userNotifications';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('User Notifications successfully displays notifications.', async () => {
  fetchMock.get('/api/notifications', { status: 200, body: { notifications: ['Notification 1'] } });

  await act(async () => { render(<MemoryRouter><UserNotifications /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByTestId('notifications-button')); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Notification 1')).toBeInTheDocument();
}, 10000);

test('User Notifications fails and displays error message.', async () => {
  fetchMock.get('/api/notifications', { status: 500 });

  await act(async () => { render(<MemoryRouter><UserNotifications /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByTestId('notifications-button')); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Failed to fetch notifications')).toBeInTheDocument();
}, 10000);

