import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import DeleteFinancialGoal from './deleteFinancialGoal';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('successfully deletes a financial goal', async () => {
  fetchMock.delete('/api/goal/1', { status: 200, body: {} });

  await act(async () => {
    render(<MemoryRouter><DeleteFinancialGoal /></MemoryRouter>);
  });

  await act(async () => {
    fireEvent.click(screen.getByTestId('delete-button'));
  });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Goal deleted successfully!')).toBeInTheDocument();
}, 10000);

test('fails to delete a financial goal', async () => {
  fetchMock.delete('/api/goal/1', { status: 404, body: { error: 'Goal not found' } });

  await act(async () => {
    render(<MemoryRouter><DeleteFinancialGoal /></MemoryRouter>);
  });

  await act(async () => {
    fireEvent.click(screen.getByTestId('delete-button'));
  });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Goal not found')).toBeInTheDocument();
}, 10000);

