import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import SetSavingsTarget from './setSavingsTarget';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('successfully sets savings targets', async () => {
  fetchMock.post('/api/savings/target', { status: 201, body: {} });

  await act(async () => {
    render(<MemoryRouter><SetSavingsTarget /></MemoryRouter>);
  });

  await act(async () => {
    fireEvent.change(screen.getByTestId('target-input'), { target: { value: 'Save $2000' } });
    fireEvent.click(screen.getByTestId('submit-button'));
  });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Savings target set successfully!')).toBeInTheDocument();
}, 10000);

test('fails to set savings targets', async () => {
  fetchMock.post('/api/savings/target', { status: 400, body: { error: 'Invalid target' } });

  await act(async () => {
    render(<MemoryRouter><SetSavingsTarget /></MemoryRouter>);
  });

  await act(async () => {
    fireEvent.change(screen.getByTestId('target-input'), { target: { value: '' } });
    fireEvent.click(screen.getByTestId('submit-button'));
  });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Invalid target')).toBeInTheDocument();
}, 10000);