import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import TrackProgress from './trackFinancialGoal';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('successfully tracks progress towards a financial goal', async () => {
  fetchMock.get('/api/goal/progress/1', { status: 200, body: { progress: 50 } });

  await act(async () => {
    render(<MemoryRouter><TrackProgress /></MemoryRouter>);
  });

  await act(async () => {
    fireEvent.click(screen.getByTestId('track-button'));
  });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('50% towards your goal!')).toBeInTheDocument();
}, 10000);

test('fails to track progress towards a financial goal', async () => {
  fetchMock.get('/api/goal/progress/1', { status: 404, body: { error: 'Goal not found' } });

  await act(async () => {
    render(<MemoryRouter><TrackProgress /></MemoryRouter>);
  });

  await act(async () => {
    fireEvent.click(screen.getByTestId('track-button'));
  });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Goal not found')).toBeInTheDocument();
}, 10000);

