import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import YourComponent from './addVaccinationRecord';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('Add vaccination record successfully.', async () => {
  fetchMock.post('/api/vaccinations', 200);

  await act(async () => { render(<MemoryRouter><YourComponent /></MemoryRouter>); });
  await act(async () => { fireEvent.change(screen.getByLabelText(/vaccine/i), {target: {value: 'Rabies'}}); });
  await act(async () => { fireEvent.click(screen.getByText(/Add Vaccination/i)); });

  expect(fetchMock.calls('/api/vaccinations').length).toBe(1);
  expect(screen.getByText('Vaccination record added successfully.')).toBeInTheDocument();
}, 10000);

test('Fail to add vaccination record due to missing vaccine name.', async () => {
  fetchMock.post('/api/vaccinations', 400);

  await act(async () => { render(<MemoryRouter><YourComponent /></MemoryRouter>); });
  await act(async () => { fireEvent.change(screen.getByLabelText(/vaccine/i), {target: {value: ''}}); });
  await act(async () => { fireEvent.click(screen.getByText(/Add Vaccination/i)); });

  expect(fetchMock.calls('/api/vaccinations').length).toBe(1);
  expect(screen.getByText('Vaccine name is required.')).toBeInTheDocument();
}, 10000);

