import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import Community from './editPetMilestones';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('Successfully edits a pet milestone', async () => {
  fetchMock.put('/api/milestones/edit', { status: 200 });

  await act(async () => { render(<MemoryRouter><Community /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByTestId('edit-milestone-button', { name: /edit/i })); });
  await act(async () => { fireEvent.change(screen.getByTestId('milestone-input'), { target: { value: 'Learned to Fetch' } }); });
  await act(async () => { fireEvent.click(screen.getByTestId('save-milestone-button')); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Milestone updated successfully')).toBeInTheDocument();
}, 10000);

test('Fails to edit a pet milestone', async () => {
  fetchMock.put('/api/milestones/edit', { status: 400 });

  await act(async () => { render(<MemoryRouter><Community /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByTestId('edit-milestone-button', { name: /edit/i })); });
  await act(async () => { fireEvent.click(screen.getByTestId('save-milestone-button')); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Failed to update milestone')).toBeInTheDocument();
}, 10000);

