import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import DeleteAlbumComponent from './deleteAlbum';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('Users can successfully delete an album.', async () => {
  fetchMock.delete('/api/albums', { success: true });

  await act(async () => { render(<MemoryRouter><DeleteAlbumComponent /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByTestId('delete-album-button')); });

  expect(fetchMock.calls().length).toEqual(1);
  expect(screen.queryByText('Album deleted')).toBeInTheDocument();
}, 10000);

test('Shows an error message when deleting album fails.', async () => {
  fetchMock.delete('/api/albums', { success: false });

  await act(async () => { render(<MemoryRouter><DeleteAlbumComponent /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByTestId('delete-album-button')); });

  expect(fetchMock.calls().length).toEqual(1);
  expect(screen.getByText('Failed to delete album')).toBeInTheDocument();
}, 10000);

