import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import PropertyListing from './displayPropertyTaxInformation';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('shows property tax details for a listing', async () => {
  fetchMock.get('/property/1/tax', { body: {} });

  await act(async () => { render(<MemoryRouter><PropertyListing /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByTestId('property1Tax')); });

  expect(fetchMock.calls().length).toBe(1);
  expect(screen.getByTestId('taxInfo')).toBeInTheDocument();
}, 10000);

test('fails to display property tax information due to network error', async () => {
  fetchMock.get('/property/1/tax', 500);

  await act(async () => { render(<MemoryRouter><PropertyListing /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByTestId('property1Tax')); });

  expect(fetchMock.calls().length).toBe(1);
  expect(screen.getByText('Failed to load property tax information')).toBeInTheDocument();
}, 10000);

