import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import SharePropertyListings from './sharePropertyListings';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('successfully shares property listings', async () => {
  fetchMock.post('/api/share', 200);

  await act(async () => { render(<MemoryRouter><SharePropertyListings /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByTestId('share-listing-btn')); });

  expect(fetchMock.calls()).toHaveLength(1); 
  expect(screen.getByTestId('share-success')).toBeInTheDocument();
}, 10000);

test('fails to share property listings and shows error message', async () => {
  fetchMock.post('/api/share', 500);

  await act(async () => { render(<MemoryRouter><SharePropertyListings /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByTestId('share-listing-btn')); });

  expect(fetchMock.calls()).toHaveLength(1); 
  expect(screen.getByTestId('share-error')).toBeInTheDocument();
}, 10000);

