import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import OpenHouseSchedule from './viewOpenHouseSchedule';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('View open house schedule successfully', async () => {
  fetchMock.get('/api/open-house-schedule', { schedule: 'Sun 2-4 PM' });

  await act(async () => { render(<MemoryRouter><OpenHouseSchedule /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByTestId('view-schedule-btn')); });

  expect(fetchMock.calls().length).toBe(1);
  expect(screen.getByText('Sun 2-4 PM')).toBeInTheDocument();
}, 10000);

test('View open house schedule fails with error', async () => {
  fetchMock.get('/api/open-house-schedule', 500);

  await act(async () => { render(<MemoryRouter><OpenHouseSchedule /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByTestId('view-schedule-btn')); });

  expect(fetchMock.calls().length).toBe(1);
  expect(screen.getByText('Error fetching open house schedule.')).toBeInTheDocument();
}, 10000);

