import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import MyComponent from './deleteRecipeRating';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('Successfully delete a recipe rating', async () => {
  fetchMock.delete('/api/delete-rating', { status: 200 });

  await act(async () => { render(<MemoryRouter><MyComponent /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByTestId('delete-rate-button')); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByTestId('delete-rate-message')).toBeInTheDocument();
}, 10000);

test('Fail to delete a recipe rating with error message', async () => {
  fetchMock.delete('/api/delete-rating', 500);

  await act(async () => { render(<MemoryRouter><MyComponent /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByTestId('delete-rate-button')); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByTestId('error-message')).toBeInTheDocument();
}, 10000);

