import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import MyComponent from './editRecipeRating';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('Successfully edit a recipe rating', async () => {
  fetchMock.put('/api/edit-rating', { status: 200 });

  await act(async () => { render(<MemoryRouter><MyComponent /></MemoryRouter>); });
  await act(async () => { fireEvent.change(screen.getByTestId('rate-input'), { target: { value: '4' } }); });
  await act(async () => { fireEvent.click(screen.getByTestId('edit-rate-button')); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByTestId('edit-rate-message')).toBeInTheDocument();
}, 10000);

test('Fail to edit recipe rating with error message', async () => {
  fetchMock.put('/api/edit-rating', 500);

  await act(async () => { render(<MemoryRouter><MyComponent /></MemoryRouter>); });
  await act(async () => { fireEvent.change(screen.getByTestId('rate-input'), { target: { value: '4' } }); });
  await act(async () => { fireEvent.click(screen.getByTestId('edit-rate-button')); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByTestId('error-message')).toBeInTheDocument();
}, 10000);

