import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import ListSavedRecipesComponent from './listSavedRecipes';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('successfully fetches user\'s saved recipes', async () => {
  fetchMock.get('/saved-recipes', { recipes: ['Recipe 1', 'Recipe 2'] });

  await act(async () => { render(<MemoryRouter><ListSavedRecipesComponent /></MemoryRouter>); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Recipe 1')).toBeInTheDocument();
  expect(screen.getByText('Recipe 2')).toBeInTheDocument();
}, 10000);

test('shows error message when failing to fetch user\'s saved recipes', async () => {
  fetchMock.get('/saved-recipes', 500);

  await act(async () => { render(<MemoryRouter><ListSavedRecipesComponent /></MemoryRouter>); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Failed to fetch saved recipes')).toBeInTheDocument();
}, 10000);

