import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import Profile from './notificationForProfileUpdates';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('should send a notification when a profile is updated', async () => {
  fetchMock.post('/api/profile/update', { success: true });

  await act(async () => { render(<MemoryRouter><Profile /></MemoryRouter>); });
  await act(async () => { fireEvent.change(screen.getByTestId('profile-input'), {target: {value: 'new info'}}); });
  await act(async () => { fireEvent.click(screen.getByTestId('save-profile-button')); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByTestId('notification')).toBeInTheDocument();
}, 10000);

test('should handle error when notification sending fails for a profile update', async () => {
  fetchMock.post('/api/profile/update', 500);

  await act(async () => { render(<MemoryRouter><Profile /></MemoryRouter>); });
  await act(async () => { fireEvent.change(screen.getByTestId('profile-input'), {target: {value: 'new info'}}); });
  await act(async () => { fireEvent.click(screen.getByTestId('save-profile-button')); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByTestId('error-message')).toBeInTheDocument();
}, 10000);