import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import TaskApp from './taskPermissions';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('Set task-specific permissions for users successfully', async () => {
  fetchMock.post('/set-task-permissions', { status: 200, body: { success: true } });

  await act(async () => { render(<MemoryRouter><TaskApp /></MemoryRouter>); });
  await act(async () => { fireEvent.change(screen.getByTestId('task-select'), { target: { value: 'Task1' } }); });
  await act(async () => { fireEvent.change(screen.getByTestId('permission-select'), { target: { value: 'edit' } }); });
  await act(async () => { fireEvent.click(screen.getByTestId('set-permission-button')); });

  expect(fetchMock.calls('/set-task-permissions').length).toBe(1);
  expect(screen.getByText('Permissions set successfully')).toBeInTheDocument();
}, 10000);

test('Fail to set task-specific permissions for users due to server error', async () => {
  fetchMock.post('/set-task-permissions', { status: 500, body: { success: false } });

  await act(async () => { render(<MemoryRouter><TaskApp /></MemoryRouter>); });
  await act(async () => { fireEvent.change(screen.getByTestId('task-select'), { target: { value: 'Task1' } }); });
  await act(async () => { fireEvent.change(screen.getByTestId('permission-select'), { target: { value: 'edit' } }); });
  await act(async () => { fireEvent.click(screen.getByTestId('set-permission-button')); });

  expect(fetchMock.calls('/set-task-permissions').length).toBe(1);
  expect(screen.getByText('Error setting permissions')).toBeInTheDocument();
}, 10000);

