import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import App from './provideWeatherForecasts';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('should render weather forecasts for travel dates', async () => {
  fetchMock.get('/api/weather', { weather: ['Sunny', 'Rainy'] });

  await act(async () => { render(<MemoryRouter><App /></MemoryRouter>); });
  await act(async () => { fireEvent.change(screen.getByPlaceholderText('Enter travel dates'), { target: { value: '2023-12-25' } }); });
  await act(async () => { fireEvent.click(screen.getByText('Get Weather')); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Sunny')).toBeInTheDocument();
}, 10000);

test('should show error if fetching weather forecasts fails', async () => {
  fetchMock.get('/api/weather', 500);

  await act(async () => { render(<MemoryRouter><App /></MemoryRouter>); });
  await act(async () => { fireEvent.change(screen.getByPlaceholderText('Enter travel dates'), { target: { value: '2023-12-25' } }); });
  await act(async () => { fireEvent.click(screen.getByText('Get Weather')); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Failed to load weather forecasts')).toBeInTheDocument();
}, 10000);

