import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import PaymentComponent from './validatePaymentInformation';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('Valid payment information should be processed successfully.', async () => {
  fetchMock.post('/api/payment', 200);

  await act(async () => { render(<MemoryRouter><PaymentComponent /></MemoryRouter>); });
  await act(async () => { fireEvent.change(screen.getByTestId('card-number'), { target: { value: '1234567890123456' } }); });
  await act(async () => { fireEvent.click(screen.getByTestId('submit-payment')); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByTestId('success-message')).toBeInTheDocument();
}, 10000);

test('Invalid payment information should show error message.', async () => {
  fetchMock.post('/api/payment', 400);

  await act(async () => { render(<MemoryRouter><PaymentComponent /></MemoryRouter>); });
  await act(async () => { fireEvent.change(screen.getByTestId('card-number'), { target: { value: '123' } }); });
  await act(async () => { fireEvent.click(screen.getByTestId('submit-payment')); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByTestId('error-message')).toBeInTheDocument();
}, 10000);

