import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import WeatherApp from './fetchCurrentHumidity';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('Successfully retrieves the current humidity for a given location', async () => {
  fetchMock.get('/api/current-humidity?location=NYC', { humidity: 65 });

  await act(async () => { render(<MemoryRouter><WeatherApp /></MemoryRouter>); });
  await act(async () => { fireEvent.change(screen.getByLabelText('Location Input'), { target: { value: 'NYC' } }); });
  await act(async () => { fireEvent.click(screen.getByText('Get Humidity')); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('65%')).toBeInTheDocument();
}, 10000);

test('Fails to retrieve the current humidity if the API returns an error', async () => {
  fetchMock.get('/api/current-humidity?location=NYC', { status: 500 });

  await act(async () => { render(<MemoryRouter><WeatherApp /></MemoryRouter>); });
  await act(async () => { fireEvent.change(screen.getByLabelText('Location Input'), { target: { value: 'NYC' } }); });
  await act(async () => { fireEvent.click(screen.getByText('Get Humidity')); });

  expect(fetchMock.calls()).toHaveLength(1);
  expect(screen.getByText('Error fetching humidity')).toBeInTheDocument();
}, 10000);

