import React from 'react';
import { render, screen, act, fireEvent } from '@testing-library/react';
import { MemoryRouter } from 'react-router-dom';
import fetchMock from 'fetch-mock';
import '@testing-library/jest-dom';
import WeatherApp from './fetchSevereWeatherAlerts';

afterEach(() => {
  fetchMock.reset();
  fetchMock.restore();
});

test('fetchSevereWeatherAlerts successfully retrieves alerts', async () => {
  fetchMock.getOnce('/api/severe-weather-alerts', {
    status: 200,
    body: [{ id: 1, alert: 'Tornado Warning' }],
  });

  await act(async () => { render(<MemoryRouter><WeatherApp /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByText('Fetch Alerts')); });

  expect(fetchMock.called('/api/severe-weather-alerts')).toBeTruthy();
  expect(screen.getByText(/Tornado Warning/)).toBeInTheDocument();
}, 10000);

test('fetchSevereWeatherAlerts fails to retrieve alerts', async () => {
  fetchMock.getOnce('/api/severe-weather-alerts', 404);

  await act(async () => { render(<MemoryRouter><WeatherApp /></MemoryRouter>); });
  await act(async () => { fireEvent.click(screen.getByText('Fetch Alerts')); });

  expect(fetchMock.called('/api/severe-weather-alerts')).toBeTruthy();
  expect(screen.getByText(/Failed to retrieve severe weather alerts/)).toBeInTheDocument();
}, 10000);

